Package 'factset.protobuf.stach.v2'

Title: 'FactSet' 'STACH V2' Library
Description: Generates 'RProtobuf' classes for 'FactSet' 'STACH V2' tabular format which represents complex multi-dimensional array of data. These classes help in the 'serialization' and 'deserialization' of 'STACH V2' formatted data. See 'GitHub' repository documentation for more information.
Authors: Charlie Mathis [aut, cre]
Maintainer: Charlie Mathis <[email protected]>
License: Apache License 2.0
Version: 1.0.6
Built: 2026-06-02 08:43:05 UTC
Source: https://github.com/cran/factset.protobuf.stach.v2

Help Index


factset.protobuf.stach.v2

Description

The purpose of this library is to help in the serialization and de-serialization of the FactSet STACH v2 format represented using Google Protocol buffers. This library has the required FactSet STACH v2 Protobuf files and the helper serialization related methods are provided by RProtobuf library which is an internal dependency.

Usage

stachFormatdata <- read( factset.protobuf.stach.v2.Package, input='path of your stach file' )

Arguments

package

Stach Data which is represented as a Package object

input

Input file which is in binary format

Examples

## Not run: 
# an example to Read column organized file data from a connection
read( factset.protobuf.stach.v2.Package, input = 'path of your stach file' )

# an example to Read row organized file data from a connection
read( factset.protobuf.stach.v2.RowOrganizedPackage, input = 'path of your stach file' )

# an example to Read the raw stach data as a character
read( factset.protobuf.stach.v2.Package, input = as.character(stachdata) )

## End(Not run)